@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.1000';
+our $VERSION = '0.1001';
 
 use v5.36;
 
@@ -335,7 +335,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.1000
+version 0.1001
 
 =head1 SYNOPSIS
 
@@ -593,11 +593,11 @@ If the B<halt> attribute is set to true, the running filter will stop.
 
 The F<eg/*.pl> program(s) in this distribution
 
-L<MIDI::RtController::Filter::Tonal> - Related module
+L<curry>
 
-L<MIDI::RtController::Filter::Math> - Related module
+L<MIDI::RtController::Filter>
 
-L<MIDI::RtController::Filter::Drums> - Related module
+L<IO::Async::Timer::Countdown>
 
 L<IO::Async::Timer::Periodic>
 
@@ -611,8 +611,6 @@ L<Types::MIDI>
 
 L<Types::Common::Numeric>
 
-L<Types::Standard>
-
 =head1 AUTHOR
 
 Gene Boggs <gene.boggs@gmail.com>
